# eric7.QScintilla.Lexers.LexerPython

Module implementing a Python lexer with some additional methods.

### Global Attributes

None

### Classes

LexerPython | Subclass to implement some additional lexer dependant methods.

### Functions

None

## LexerPython

Subclass to implement some additional lexer dependant methods.

### Derived from

SubstyledLexer, QsciLexerPython

### Class Attributes

None

### Class Methods

None

### Methods

LexerPython | PyQt5 PyQt6 Qsci Qt Qt3DAnimation Qt3DCore Qt3DExtras Qt3DInput Qt3DLogic Qt3DRender QtBluetooth QtChart QtCharts QtCore QtDataVisualization QtDBus QtDesigner QtGui QtHelp QtLocation QtMacExtras QtMultimedia QtMultimediaWidgets QtNetwork QtNetworkAuth QtNfc QtOpenGL QtOpenGLWidgets QtPositioning QtPrintSupport QtPurchasing QtQml QtQuick QtQuick3D QtQuickWidgets QtRemoteObjects QtSensors QtSerialPort QtSql QtSvg QtSvgWidgets QtTest QtTextToSpeech QtWebChannel QtWebEngine QtWebEngineCore QtWebEngineWidgets QtWebSockets QtWidgets QtWinExtras QtX11Extras QtXml QtXmlPatterns sip
autoCompletionWordSeparators | Public method to return the list of separators for autocompletion.
defaultKeywords | Public method to get the default keywords.
getIndentationDifference | Public method to determine the difference for the new indentation.
initProperties | Public slot to initialize the properties.
isCommentStyle | Public method to check, if a style is a comment style.
isStringStyle | Public method to check, if a style is a string style.
language | Public method to get the lexer language.
maximumKeywordSet | Public method to get the maximum keyword set.

### Static Methods

None

#### LexerPython (Constructor)

LexerPython(variant="", parent=None)

PyQt5 PyQt6 Qsci Qt Qt3DAnimation Qt3DCore Qt3DExtras Qt3DInput Qt3DLogic Qt3DRender QtBluetooth QtChart QtCharts QtCore QtDataVisualization QtDBus QtDesigner QtGui QtHelp QtLocation QtMacExtras QtMultimedia QtMultimediaWidgets QtNetwork QtNetworkAuth QtNfc QtOpenGL QtOpenGLWidgets QtPositioning QtPrintSupport QtPurchasing QtQml QtQuick QtQuick3D QtQuickWidgets QtRemoteObjects QtSensors QtSerialPort QtSql QtSvg QtSvgWidgets QtTest QtTextToSpeech QtWebChannel QtWebEngine QtWebEngineCore QtWebEngineWidgets QtWebSockets QtWidgets QtWinExtras QtX11Extras QtXml QtXmlPatterns sip

#### LexerPython.autoCompletionWordSeparators

autoCompletionWordSeparators()

Public method to return the list of separators for autocompletion.

Return:
  list of separators (list of strings)

#### LexerPython.defaultKeywords

defaultKeywords(kwSet)

Public method to get the default keywords.

kwSet
  number of the keyword set (integer)

Return:
  string giving the keywords (string) or None

#### LexerPython.getIndentationDifference

getIndentationDifference(line, editor)

Public method to determine the difference for the new indentation.

line
  line to perform the calculation for (integer)
editor
  QScintilla editor

Return:
  amount of difference in indentation (integer)

#### LexerPython.initProperties

initProperties()

Public slot to initialize the properties.

#### LexerPython.isCommentStyle

isCommentStyle(style)

Public method to check, if a style is a comment style.

style
  style to check (integer)

Return:
  flag indicating a comment style (boolean)

#### LexerPython.isStringStyle

isStringStyle(style)

Public method to check, if a style is a string style.

style
  style to check (integer)

Return:
  flag indicating a string style (boolean)

#### LexerPython.language

language()

Public method to get the lexer language.

Return:
  lexer language (string)

#### LexerPython.maximumKeywordSet

maximumKeywordSet()

Public method to get the maximum keyword set.

Return:
  maximum keyword set (integer)

Up